@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.4.1.  */
+/* A Bison parser, made by GNU Bison 3.5.3.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -48,7 +48,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.4.1"
+#define YYBISON_VERSION "3.5.3"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -156,6 +156,15 @@ static void print_help_topics(void);
 
 #line 158 "ginsh_parser.cpp"
 
+# ifndef YY_CAST
+#  ifdef __cplusplus
+#   define YY_CAST(Type, Val) static_cast<Type> (Val)
+#   define YY_REINTERPRET_CAST(Type, Val) reinterpret_cast<Type> (Val)
+#  else
+#   define YY_CAST(Type, Val) ((Type) (Val))
+#   define YY_REINTERPRET_CAST(Type, Val) ((Type) (Val))
+#  endif
+# endif
 # ifndef YY_NULLPTR
 #  if defined __cplusplus
 #   if 201103L <= __cplusplus
@@ -267,36 +276,83 @@ int yyparse (void);
 # undef short
 #endif
 
-#ifdef YYTYPE_UINT8
-typedef YYTYPE_UINT8 yytype_uint8;
-#else
-typedef unsigned char yytype_uint8;
+/* On compilers that do not define __PTRDIFF_MAX__ etc., make sure
+   <limits.h> and (if available) <stdint.h> are included
+   so that the code can choose integer types of a good width.  */
+
+#ifndef __PTRDIFF_MAX__
+# include <limits.h> /* INFRINGES ON USER NAME SPACE */
+# if defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
+#  include <stdint.h> /* INFRINGES ON USER NAME SPACE */
+#  define YY_STDINT_H
+# endif
 #endif
 
-#ifdef YYTYPE_INT8
-typedef YYTYPE_INT8 yytype_int8;
+/* Narrow types that promote to a signed type and that can represent a
+   signed or unsigned integer of at least N bits.  In tables they can
+   save space and decrease cache pressure.  Promoting to a signed type
+   helps avoid bugs in integer arithmetic.  */
+
+#ifdef __INT_LEAST8_MAX__
+typedef __INT_LEAST8_TYPE__ yytype_int8;
+#elif defined YY_STDINT_H
+typedef int_least8_t yytype_int8;
 #else
 typedef signed char yytype_int8;
 #endif
 
-#ifdef YYTYPE_UINT16
-typedef YYTYPE_UINT16 yytype_uint16;
-#else
-typedef unsigned short yytype_uint16;
-#endif
-
-#ifdef YYTYPE_INT16
-typedef YYTYPE_INT16 yytype_int16;
+#ifdef __INT_LEAST16_MAX__
+typedef __INT_LEAST16_TYPE__ yytype_int16;
+#elif defined YY_STDINT_H
+typedef int_least16_t yytype_int16;
 #else
 typedef short yytype_int16;
 #endif
 
+#if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
+typedef __UINT_LEAST8_TYPE__ yytype_uint8;
+#elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
+       && UINT_LEAST8_MAX <= INT_MAX)
+typedef uint_least8_t yytype_uint8;
+#elif !defined __UINT_LEAST8_MAX__ && UCHAR_MAX <= INT_MAX
+typedef unsigned char yytype_uint8;
+#else
+typedef short yytype_uint8;
+#endif
+
+#if defined __UINT_LEAST16_MAX__ && __UINT_LEAST16_MAX__ <= __INT_MAX__
+typedef __UINT_LEAST16_TYPE__ yytype_uint16;
+#elif (!defined __UINT_LEAST16_MAX__ && defined YY_STDINT_H \
+       && UINT_LEAST16_MAX <= INT_MAX)
+typedef uint_least16_t yytype_uint16;
+#elif !defined __UINT_LEAST16_MAX__ && USHRT_MAX <= INT_MAX
+typedef unsigned short yytype_uint16;
+#else
+typedef int yytype_uint16;
+#endif
+
+#ifndef YYPTRDIFF_T
+# if defined __PTRDIFF_TYPE__ && defined __PTRDIFF_MAX__
+#  define YYPTRDIFF_T __PTRDIFF_TYPE__
+#  define YYPTRDIFF_MAXIMUM __PTRDIFF_MAX__
+# elif defined PTRDIFF_MAX
+#  ifndef ptrdiff_t
+#   include <stddef.h> /* INFRINGES ON USER NAME SPACE */
+#  endif
+#  define YYPTRDIFF_T ptrdiff_t
+#  define YYPTRDIFF_MAXIMUM PTRDIFF_MAX
+# else
+#  define YYPTRDIFF_T long
+#  define YYPTRDIFF_MAXIMUM LONG_MAX
+# endif
+#endif
+
 #ifndef YYSIZE_T
 # ifdef __SIZE_TYPE__
 #  define YYSIZE_T __SIZE_TYPE__
 # elif defined size_t
 #  define YYSIZE_T size_t
-# elif ! defined YYSIZE_T
+# elif defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
@@ -304,7 +360,19 @@ typedef short yytype_int16;
 # endif
 #endif
 
-#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)
+#define YYSIZE_MAXIMUM                                  \
+  YY_CAST (YYPTRDIFF_T,                                 \
+           (YYPTRDIFF_MAXIMUM < YY_CAST (YYSIZE_T, -1)  \
+            ? YYPTRDIFF_MAXIMUM                         \
+            : YY_CAST (YYSIZE_T, -1)))
+
+#define YYSIZEOF(X) YY_CAST (YYPTRDIFF_T, sizeof (X))
+
+/* Stored state numbers (used for stacks). */
+typedef yytype_int8 yy_state_t;
+
+/* State numbers in computations.  */
+typedef int yy_state_fast_t;
 
 #ifndef YY_
 # if defined YYENABLE_NLS && YYENABLE_NLS
@@ -318,22 +386,20 @@ typedef short yytype_int16;
 # endif
 #endif
 
-#ifndef YY_ATTRIBUTE
-# if (defined __GNUC__                                               \
-      && (2 < __GNUC__ || (__GNUC__ == 2 && 96 <= __GNUC_MINOR__)))  \
-     || defined __SUNPRO_C && 0x5110 <= __SUNPRO_C
-#  define YY_ATTRIBUTE(Spec) __attribute__(Spec)
+#ifndef YY_ATTRIBUTE_PURE
+# if defined __GNUC__ && 2 < __GNUC__ + (96 <= __GNUC_MINOR__)
+#  define YY_ATTRIBUTE_PURE __attribute__ ((__pure__))
 # else
-#  define YY_ATTRIBUTE(Spec) /* empty */
+#  define YY_ATTRIBUTE_PURE
 # endif
 #endif
 
-#ifndef YY_ATTRIBUTE_PURE
-# define YY_ATTRIBUTE_PURE   YY_ATTRIBUTE ((__pure__))
-#endif
-
 #ifndef YY_ATTRIBUTE_UNUSED
-# define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
+# if defined __GNUC__ && 2 < __GNUC__ + (7 <= __GNUC_MINOR__)
+#  define YY_ATTRIBUTE_UNUSED __attribute__ ((__unused__))
+# else
+#  define YY_ATTRIBUTE_UNUSED
+# endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
@@ -345,11 +411,11 @@ typedef short yytype_int16;
 
 #if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
-# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
-    _Pragma ("GCC diagnostic push") \
-    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")\
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                            \
+    _Pragma ("GCC diagnostic push")                                     \
+    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
     _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
-# define YY_IGNORE_MAYBE_UNINITIALIZED_END \
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
     _Pragma ("GCC diagnostic pop")
 #else
 # define YY_INITIAL_VALUE(Value) Value
@@ -362,6 +428,18 @@ typedef short yytype_int16;
 # define YY_INITIAL_VALUE(Value) /* Nothing. */
 #endif
 
+#if defined __cplusplus && defined __GNUC__ && ! defined __ICC && 6 <= __GNUC__
+# define YY_IGNORE_USELESS_CAST_BEGIN                          \
+    _Pragma ("GCC diagnostic push")                            \
+    _Pragma ("GCC diagnostic ignored \"-Wuseless-cast\"")
+# define YY_IGNORE_USELESS_CAST_END            \
+    _Pragma ("GCC diagnostic pop")
+#endif
+#ifndef YY_IGNORE_USELESS_CAST_BEGIN
+# define YY_IGNORE_USELESS_CAST_BEGIN
+# define YY_IGNORE_USELESS_CAST_END
+#endif
+
 
 #define YY_ASSERT(E) ((void) (0 && (E)))
 
@@ -440,17 +518,17 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss_alloc;
+  yy_state_t yyss_alloc;
   YYSTYPE yyvs_alloc;
 };
 
 /* The size of the maximum gap between one aligned stack and the next.  */
-# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
+# define YYSTACK_GAP_MAXIMUM (YYSIZEOF (union yyalloc) - 1)
 
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
+     ((N) * (YYSIZEOF (yy_state_t) + YYSIZEOF (YYSTYPE)) \
       + YYSTACK_GAP_MAXIMUM)
 
 # define YYCOPY_NEEDED 1
@@ -463,11 +541,11 @@ union yyalloc
 # define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
     do                                                                  \
       {                                                                 \
-        YYSIZE_T yynewbytes;                                            \
+        YYPTRDIFF_T yynewbytes;                                         \
         YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
         Stack = &yyptr->Stack_alloc;                                    \
-        yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
-        yyptr += yynewbytes / sizeof (*yyptr);                          \
+        yynewbytes = yystacksize * YYSIZEOF (*Stack) + YYSTACK_GAP_MAXIMUM; \
+        yyptr += yynewbytes / YYSIZEOF (*yyptr);                        \
       }                                                                 \
     while (0)
 
@@ -479,12 +557,12 @@ union yyalloc
 # ifndef YYCOPY
 #  if defined __GNUC__ && 1 < __GNUC__
 #   define YYCOPY(Dst, Src, Count) \
-      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
+      __builtin_memcpy (Dst, Src, YY_CAST (YYSIZE_T, (Count)) * sizeof (*(Src)))
 #  else
 #   define YYCOPY(Dst, Src, Count)              \
       do                                        \
         {                                       \
-          YYSIZE_T yyi;                         \
+          YYPTRDIFF_T yyi;                      \
           for (yyi = 0; yyi < (Count); yyi++)   \
             (Dst)[yyi] = (Src)[yyi];            \
         }                                       \
@@ -510,14 +588,15 @@ union yyalloc
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   282
 
+
 /* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
    as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  (0 <= (YYX) && (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
    as returned by yylex.  */
-static const yytype_uint8 yytranslate[] =
+static const yytype_int8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -552,7 +631,7 @@ static const yytype_uint8 yytranslate[] =
 
 #if YYDEBUG
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
-static const yytype_uint16 yyrline[] =
+static const yytype_int16 yyrline[] =
 {
        0,   143,   143,   144,   147,   148,   157,   165,   173,   187,
      195,   203,   204,   205,   206,   207,   208,   209,   210,   211,
@@ -584,7 +663,7 @@ static const char *const yytname[] =
 # ifdef YYPRINT
 /* YYTOKNUM[NUM] -- (External) token number corresponding to the
    (internal) symbol number NUM (which must be that of a token).  */
-static const yytype_uint16 yytoknum[] =
+static const yytype_int16 yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
@@ -594,14 +673,14 @@ static const yytype_uint16 yytoknum[] =
 };
 # endif
 
-#define YYPACT_NINF -36
+#define YYPACT_NINF (-36)
 
-#define yypact_value_is_default(Yystate) \
-  (!!((Yystate) == (-36)))
+#define yypact_value_is_default(Yyn) \
+  ((Yyn) == YYPACT_NINF)
 
-#define YYTABLE_NINF -1
+#define YYTABLE_NINF (-1)
 
-#define yytable_value_is_error(Yytable_value) \
+#define yytable_value_is_error(Yyn) \
   0
 
   /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
@@ -626,7 +705,7 @@ static const yytype_int16 yypact[] =
   /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
      Performed when YYTABLE does not specify something else to do.  Zero
      means the default is an error.  */
-static const yytype_uint8 yydefact[] =
+static const yytype_int8 yydefact[] =
 {
        2,     0,     1,     0,    30,    31,    33,    34,    35,    36,
       37,    18,    19,     0,     0,     0,     0,    26,    20,    21,
@@ -658,7 +737,7 @@ static const yytype_int8 yydefgoto[] =
   /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
      positive, shift that token.  If negative, reduce the rule whose
      number is the opposite.  If YYTABLE_NINF, syntax error.  */
-static const yytype_uint8 yytable[] =
+static const yytype_int8 yytable[] =
 {
       33,    36,    34,    35,    70,    71,     4,     5,     6,     7,
        8,     9,    10,    37,    38,   102,    68,    69,    39,    70,
@@ -730,7 +809,7 @@ static const yytype_int8 yycheck[] =
 
   /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
      symbol of state STATE-NUM.  */
-static const yytype_uint8 yystos[] =
+static const yytype_int8 yystos[] =
 {
        0,    49,     0,     1,     3,     4,     5,     6,     7,     8,
        9,    14,    15,    16,    17,    18,    19,    20,    21,    22,
@@ -748,7 +827,7 @@ static const yytype_uint8 yystos[] =
 };
 
   /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
-static const yytype_uint8 yyr1[] =
+static const yytype_int8 yyr1[] =
 {
        0,    48,    49,    49,    50,    50,    50,    50,    50,    50,
       50,    50,    50,    50,    50,    50,    50,    50,    50,    50,
@@ -760,7 +839,7 @@ static const yytype_uint8 yyr1[] =
 };
 
   /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
-static const yytype_uint8 yyr2[] =
+static const yytype_int8 yyr2[] =
 {
        0,     2,     0,     2,     1,     2,     2,     5,     5,     5,
        5,     2,     2,     2,     2,     2,     2,     2,     1,     1,
@@ -854,7 +933,9 @@ yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
   if (yytype < YYNTOKENS)
     YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   YYUSE (yytype);
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
 
@@ -878,7 +959,7 @@ yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
 `------------------------------------------------------------------*/
 
 static void
-yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
+yy_stack_print (yy_state_t *yybottom, yy_state_t *yytop)
 {
   YYFPRINTF (stderr, "Stack now");
   for (; yybottom <= yytop; yybottom++)
@@ -901,19 +982,19 @@ do {                                                            \
 `------------------------------------------------*/
 
 static void
-yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
+yy_reduce_print (yy_state_t *yyssp, YYSTYPE *yyvsp, int yyrule)
 {
-  unsigned long yylno = yyrline[yyrule];
+  int yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
-  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
+  YYFPRINTF (stderr, "Reducing stack by rule %d (line %d):\n",
              yyrule - 1, yylno);
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
-                       yystos[yyssp[yyi + 1 - yynrhs]],
+                       yystos[+yyssp[yyi + 1 - yynrhs]],
                        &yyvsp[(yyi + 1) - (yynrhs)]
                                               );
       YYFPRINTF (stderr, "\n");
@@ -958,13 +1039,13 @@ int yydebug;
 
 # ifndef yystrlen
 #  if defined __GLIBC__ && defined _STRING_H
-#   define yystrlen strlen
+#   define yystrlen(S) (YY_CAST (YYPTRDIFF_T, strlen (S)))
 #  else
 /* Return the length of YYSTR.  */
-static YYSIZE_T
+static YYPTRDIFF_T
 yystrlen (const char *yystr)
 {
-  YYSIZE_T yylen;
+  YYPTRDIFF_T yylen;
   for (yylen = 0; yystr[yylen]; yylen++)
     continue;
   return yylen;
@@ -1000,12 +1081,12 @@ yystpcpy (char *yydest, const char *yysrc)
    backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
    null, do not copy; instead, return the length of what the result
    would have been.  */
-static YYSIZE_T
+static YYPTRDIFF_T
 yytnamerr (char *yyres, const char *yystr)
 {
   if (*yystr == '"')
     {
-      YYSIZE_T yyn = 0;
+      YYPTRDIFF_T yyn = 0;
       char const *yyp = yystr;
 
       for (;;)
@@ -1036,10 +1117,10 @@ yytnamerr (char *yyres, const char *yystr)
     do_not_strip_quotes: ;
     }
 
-  if (! yyres)
+  if (yyres)
+    return yystpcpy (yyres, yystr) - yyres;
+  else
     return yystrlen (yystr);
-
-  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1052,19 +1133,19 @@ yytnamerr (char *yyres, const char *yystr)
    *YYMSG_ALLOC to the required number of bytes.  Return 2 if the
    required number of bytes is too large to store.  */
 static int
-yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
-                yytype_int16 *yyssp, int yytoken)
+yysyntax_error (YYPTRDIFF_T *yymsg_alloc, char **yymsg,
+                yy_state_t *yyssp, int yytoken)
 {
-  YYSIZE_T yysize0 = yytnamerr (YY_NULLPTR, yytname[yytoken]);
-  YYSIZE_T yysize = yysize0;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *yyformat = YY_NULLPTR;
-  /* Arguments of yyformat. */
+  /* Arguments of yyformat: reported tokens (one for the "unexpected",
+     one per "expected"). */
   char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
-  /* Number of reported tokens (one for the "unexpected", one per
-     "expected"). */
+  /* Actual size of YYARG. */
   int yycount = 0;
+  /* Cumulated lengths of YYARG.  */
+  YYPTRDIFF_T yysize = 0;
 
   /* There are many possibilities here to consider:
      - If this state is a consistent state with a default action, then
@@ -1091,7 +1172,9 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
   */
   if (yytoken != YYEMPTY)
     {
-      int yyn = yypact[*yyssp];
+      int yyn = yypact[+*yyssp];
+      YYPTRDIFF_T yysize0 = yytnamerr (YY_NULLPTR, yytname[yytoken]);
+      yysize = yysize0;
       yyarg[yycount++] = yytname[yytoken];
       if (!yypact_value_is_default (yyn))
         {
@@ -1116,7 +1199,8 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                   }
                 yyarg[yycount++] = yytname[yyx];
                 {
-                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
+                  YYPTRDIFF_T yysize1
+                    = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
                   if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
                     yysize = yysize1;
                   else
@@ -1143,7 +1227,9 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
     }
 
   {
-    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
+    /* Don't count the "%s"s in the final size, but reserve room for
+       the terminator.  */
+    YYPTRDIFF_T yysize1 = yysize + (yystrlen (yyformat) - 2 * yycount) + 1;
     if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
       yysize = yysize1;
     else
@@ -1173,8 +1259,8 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
         }
       else
         {
-          yyp++;
-          yyformat++;
+          ++yyp;
+          ++yyformat;
         }
   }
   return 0;
@@ -1217,7 +1303,7 @@ int yynerrs;
 int
 yyparse (void)
 {
-    int yystate;
+    yy_state_fast_t yystate;
     /* Number of tokens to shift before error messages enabled.  */
     int yyerrstatus;
 
@@ -1229,16 +1315,16 @@ yyparse (void)
        to reallocate them elsewhere.  */
 
     /* The state stack.  */
-    yytype_int16 yyssa[YYINITDEPTH];
-    yytype_int16 *yyss;
-    yytype_int16 *yyssp;
+    yy_state_t yyssa[YYINITDEPTH];
+    yy_state_t *yyss;
+    yy_state_t *yyssp;
 
     /* The semantic value stack.  */
     YYSTYPE yyvsa[YYINITDEPTH];
     YYSTYPE *yyvs;
     YYSTYPE *yyvsp;
 
-    YYSIZE_T yystacksize;
+    YYPTRDIFF_T yystacksize;
 
   int yyn;
   int yyresult;
@@ -1252,7 +1338,7 @@ yyparse (void)
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
   char *yymsg = yymsgbuf;
-  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
+  YYPTRDIFF_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
@@ -1284,12 +1370,14 @@ yynewstate:
 
 
 /*--------------------------------------------------------------------.
-| yynewstate -- set current state (the top of the stack) to yystate.  |
+| yysetstate -- set current state (the top of the stack) to yystate.  |
 `--------------------------------------------------------------------*/
 yysetstate:
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
   YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
-  *yyssp = (yytype_int16) yystate;
+  YY_IGNORE_USELESS_CAST_BEGIN
+  *yyssp = YY_CAST (yy_state_t, yystate);
+  YY_IGNORE_USELESS_CAST_END
 
   if (yyss + yystacksize - 1 <= yyssp)
 #if !defined yyoverflow && !defined YYSTACK_RELOCATE
@@ -1297,23 +1385,23 @@ yysetstate:
 #else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
+      YYPTRDIFF_T yysize = yyssp - yyss + 1;
 
 # if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
            memory.  */
+        yy_state_t *yyss1 = yyss;
         YYSTYPE *yyvs1 = yyvs;
-        yytype_int16 *yyss1 = yyss;
 
         /* Each stack pointer address is followed by the size of the
            data in use in that stack, in bytes.  This used to be a
            conditional around just the two extra args, but that might
            be undefined if yyoverflow is a macro.  */
         yyoverflow (YY_("memory exhausted"),
-                    &yyss1, yysize * sizeof (*yyssp),
-                    &yyvs1, yysize * sizeof (*yyvsp),
+                    &yyss1, yysize * YYSIZEOF (*yyssp),
+                    &yyvs1, yysize * YYSIZEOF (*yyvsp),
                     &yystacksize);
         yyss = yyss1;
         yyvs = yyvs1;
@@ -1327,9 +1415,10 @@ yysetstate:
         yystacksize = YYMAXDEPTH;
 
       {
-        yytype_int16 *yyss1 = yyss;
+        yy_state_t *yyss1 = yyss;
         union yyalloc *yyptr =
-          (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
+          YY_CAST (union yyalloc *,
+                   YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
         if (! yyptr)
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
@@ -1343,8 +1432,10 @@ yysetstate:
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long) yystacksize));
+      YY_IGNORE_USELESS_CAST_BEGIN
+      YYDPRINTF ((stderr, "Stack size increased to %ld\n",
+                  YY_CAST (long, yystacksize)));
+      YY_IGNORE_USELESS_CAST_END
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
@@ -1410,14 +1501,13 @@ yybackup:
 
   /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
-
-  /* Discard the shifted token.  */
-  yychar = YYEMPTY;
-
   yystate = yyn;
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
   YY_IGNORE_MAYBE_UNINITIALIZED_END
+
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
   goto yynewstate;
 
 
@@ -1454,7 +1544,7 @@ yyreduce:
     {
   case 5:
 #line 148 "ginsh_parser.ypp"
-    {
+                  {
 		try {
 			cout << yyvsp[-1] << endl;
 			push(yyvsp[-1]);
@@ -1463,12 +1553,12 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1467 "ginsh_parser.cpp"
+#line 1557 "ginsh_parser.cpp"
     break;
 
   case 6:
 #line 157 "ginsh_parser.ypp"
-    {
+                  {
 		try {
 			push(yyvsp[-1]);
 		} catch (exception &e) {
@@ -1476,12 +1566,12 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1480 "ginsh_parser.cpp"
+#line 1570 "ginsh_parser.cpp"
     break;
 
   case 7:
 #line 165 "ginsh_parser.ypp"
-    {
+                                  {
 		try {
 			yyvsp[-2].print(print_tree(std::cout));
 		} catch (exception &e) {
@@ -1489,12 +1579,12 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1493 "ginsh_parser.cpp"
+#line 1583 "ginsh_parser.cpp"
     break;
 
   case 8:
 #line 173 "ginsh_parser.ypp"
-    {
+                                   {
 		try {
 			ex e = yyvsp[-2];
 			if (!e.info(info_flags::integer))
@@ -1508,12 +1598,12 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1512 "ginsh_parser.cpp"
+#line 1602 "ginsh_parser.cpp"
     break;
 
   case 9:
 #line 187 "ginsh_parser.ypp"
-    {
+                                       {
 		try {
 			yyvsp[-2].print(print_latex(std::cout)); cout << endl;
 		} catch (exception &e) {
@@ -1521,12 +1611,12 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1525 "ginsh_parser.cpp"
+#line 1615 "ginsh_parser.cpp"
     break;
 
   case 10:
 #line 195 "ginsh_parser.ypp"
-    {
+                                      {
 		try {
 			yyvsp[-2].print(print_csrc_double(std::cout)); cout << endl;
 		} catch (exception &e) {
@@ -1534,60 +1624,60 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1538 "ginsh_parser.cpp"
+#line 1628 "ginsh_parser.cpp"
     break;
 
   case 11:
 #line 203 "ginsh_parser.ypp"
-    {print_help(ex_to<symbol>(yyvsp[0]).get_name());}
-#line 1544 "ginsh_parser.cpp"
+                                {print_help(ex_to<symbol>(yyvsp[0]).get_name());}
+#line 1634 "ginsh_parser.cpp"
     break;
 
   case 12:
 #line 204 "ginsh_parser.ypp"
-    {print_help("time");}
-#line 1550 "ginsh_parser.cpp"
+                                {print_help("time");}
+#line 1640 "ginsh_parser.cpp"
     break;
 
   case 13:
 #line 205 "ginsh_parser.ypp"
-    {print_help("print");}
-#line 1556 "ginsh_parser.cpp"
+                                {print_help("print");}
+#line 1646 "ginsh_parser.cpp"
     break;
 
   case 14:
 #line 206 "ginsh_parser.ypp"
-    {print_help("iprint");}
-#line 1562 "ginsh_parser.cpp"
+                                {print_help("iprint");}
+#line 1652 "ginsh_parser.cpp"
     break;
 
   case 15:
 #line 207 "ginsh_parser.ypp"
-    {print_help("print_latex");}
-#line 1568 "ginsh_parser.cpp"
+                                {print_help("print_latex");}
+#line 1658 "ginsh_parser.cpp"
     break;
 
   case 16:
 #line 208 "ginsh_parser.ypp"
-    {print_help("print_csrc");}
-#line 1574 "ginsh_parser.cpp"
+                                {print_help("print_csrc");}
+#line 1664 "ginsh_parser.cpp"
     break;
 
   case 17:
 #line 209 "ginsh_parser.ypp"
-    {print_help_topics();}
-#line 1580 "ginsh_parser.cpp"
+                                {print_help_topics();}
+#line 1670 "ginsh_parser.cpp"
     break;
 
   case 18:
 #line 210 "ginsh_parser.ypp"
-    {YYACCEPT;}
-#line 1586 "ginsh_parser.cpp"
+                                {YYACCEPT;}
+#line 1676 "ginsh_parser.cpp"
     break;
 
   case 19:
 #line 211 "ginsh_parser.ypp"
-    {
+                     {
 		cout << "This program is free software; you can redistribute it and/or modify it under\n";
 		cout << "the terms of the GNU General Public License as published by the Free Software\n";
 		cout << "Foundation; either version 2 of the License, or (at your option) any later\n";
@@ -1600,130 +1690,130 @@ yyreduce:
 		cout << "this program. If not, write to the Free Software Foundation,\n";
 		cout << "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.\n";
 	}
-#line 1604 "ginsh_parser.cpp"
+#line 1694 "ginsh_parser.cpp"
     break;
 
   case 20:
 #line 224 "ginsh_parser.ypp"
-    {cout << "Nothing happens.\n";}
-#line 1610 "ginsh_parser.cpp"
+                                {cout << "Nothing happens.\n";}
+#line 1700 "ginsh_parser.cpp"
     break;
 
   case 21:
 #line 225 "ginsh_parser.ypp"
-    {cout << "You're not carrying anything.\n";}
-#line 1616 "ginsh_parser.cpp"
+                                {cout << "You're not carrying anything.\n";}
+#line 1706 "ginsh_parser.cpp"
     break;
 
   case 22:
 #line 226 "ginsh_parser.ypp"
-    {cout << "You're in a twisty little maze of passages, all alike.\n";}
-#line 1622 "ginsh_parser.cpp"
+                                {cout << "You're in a twisty little maze of passages, all alike.\n";}
+#line 1712 "ginsh_parser.cpp"
     break;
 
   case 23:
 #line 227 "ginsh_parser.ypp"
-    {
+                  {
 		cout << "If you were to quit now, you would score ";
 		cout << (syms.size() > 350 ? 350 : syms.size());
 		cout << " out of a possible 350.\n";
 	}
-#line 1632 "ginsh_parser.cpp"
+#line 1722 "ginsh_parser.cpp"
     break;
 
   case 24:
 #line 232 "ginsh_parser.ypp"
-    { symboltype = domain::real; }
-#line 1638 "ginsh_parser.cpp"
+                         { symboltype = domain::real; }
+#line 1728 "ginsh_parser.cpp"
     break;
 
   case 25:
 #line 233 "ginsh_parser.ypp"
-    { symboltype = domain::complex; }
-#line 1644 "ginsh_parser.cpp"
+                            { symboltype = domain::complex; }
+#line 1734 "ginsh_parser.cpp"
     break;
 
   case 26:
 #line 234 "ginsh_parser.ypp"
-    { START_TIMER }
-#line 1650 "ginsh_parser.cpp"
+                 { START_TIMER }
+#line 1740 "ginsh_parser.cpp"
     break;
 
   case 27:
 #line 234 "ginsh_parser.ypp"
-    { STOP_TIMER PRINT_TIME_USED }
-#line 1656 "ginsh_parser.cpp"
+                                             { STOP_TIMER PRINT_TIME_USED }
+#line 1746 "ginsh_parser.cpp"
     break;
 
   case 28:
 #line 235 "ginsh_parser.ypp"
-    {yyclearin; yyerrok;}
-#line 1662 "ginsh_parser.cpp"
+                                {yyclearin; yyerrok;}
+#line 1752 "ginsh_parser.cpp"
     break;
 
   case 29:
 #line 236 "ginsh_parser.ypp"
-    {yyclearin; yyerrok;}
-#line 1668 "ginsh_parser.cpp"
+                                {yyclearin; yyerrok;}
+#line 1758 "ginsh_parser.cpp"
     break;
 
   case 30:
 #line 239 "ginsh_parser.ypp"
-    {yyval = yyvsp[0];}
-#line 1674 "ginsh_parser.cpp"
+                                {yyval = yyvsp[0];}
+#line 1764 "ginsh_parser.cpp"
     break;
 
   case 31:
 #line 240 "ginsh_parser.ypp"
-    {
+                                {
 		auto i = assigned_symbol_table.find(yyvsp[0]);
 		if (i == assigned_symbol_table.end())
 			yyval = yyvsp[0];
 		else
 			yyval = i->second;
 	}
-#line 1686 "ginsh_parser.cpp"
+#line 1776 "ginsh_parser.cpp"
     break;
 
   case 32:
 #line 247 "ginsh_parser.ypp"
-    {yyval = yyvsp[-1];}
-#line 1692 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-1];}
+#line 1782 "ginsh_parser.cpp"
     break;
 
   case 33:
 #line 248 "ginsh_parser.ypp"
-    {yyval = yyvsp[0];}
-#line 1698 "ginsh_parser.cpp"
+                                {yyval = yyvsp[0];}
+#line 1788 "ginsh_parser.cpp"
     break;
 
   case 34:
 #line 249 "ginsh_parser.ypp"
-    {yyval = yyvsp[0];}
-#line 1704 "ginsh_parser.cpp"
+                                {yyval = yyvsp[0];}
+#line 1794 "ginsh_parser.cpp"
     break;
 
   case 35:
 #line 250 "ginsh_parser.ypp"
-    {yyval = exstack[0];}
-#line 1710 "ginsh_parser.cpp"
+                                {yyval = exstack[0];}
+#line 1800 "ginsh_parser.cpp"
     break;
 
   case 36:
 #line 251 "ginsh_parser.ypp"
-    {yyval = exstack[1];}
-#line 1716 "ginsh_parser.cpp"
+                                {yyval = exstack[1];}
+#line 1806 "ginsh_parser.cpp"
     break;
 
   case 37:
 #line 252 "ginsh_parser.ypp"
-    {yyval = exstack[2];}
-#line 1722 "ginsh_parser.cpp"
+                                {yyval = exstack[2];}
+#line 1812 "ginsh_parser.cpp"
     break;
 
   case 38:
 #line 253 "ginsh_parser.ypp"
-    {
+                                   {
 		auto i = find_function(yyvsp[-3], yyvsp[-1].nops());
 		if (i->second.is_ginac) {
 			yyval = ((fcnp2)(i->second.p))(ex_to<exprseq>(yyvsp[-1]), i->second.serial);
@@ -1731,185 +1821,185 @@ yyreduce:
 			yyval = (i->second.p)(ex_to<exprseq>(yyvsp[-1]));
 		}
 	}
-#line 1735 "ginsh_parser.cpp"
+#line 1825 "ginsh_parser.cpp"
     break;
 
   case 39:
 #line 261 "ginsh_parser.ypp"
-    {yyval = yyvsp[0]; Digits = ex_to<numeric>(yyvsp[0]).to_int();}
-#line 1741 "ginsh_parser.cpp"
+                                {yyval = yyvsp[0]; Digits = ex_to<numeric>(yyvsp[0]).to_int();}
+#line 1831 "ginsh_parser.cpp"
     break;
 
   case 40:
 #line 262 "ginsh_parser.ypp"
-    {yyval = yyvsp[0]; assigned_symbol_table[yyvsp[-2]] = yyvsp[0]; }
-#line 1747 "ginsh_parser.cpp"
+                                {yyval = yyvsp[0]; assigned_symbol_table[yyvsp[-2]] = yyvsp[0]; }
+#line 1837 "ginsh_parser.cpp"
     break;
 
   case 41:
 #line 263 "ginsh_parser.ypp"
-    {yyval = yyvsp[-2] == yyvsp[0];}
-#line 1753 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-2] == yyvsp[0];}
+#line 1843 "ginsh_parser.cpp"
     break;
 
   case 42:
 #line 264 "ginsh_parser.ypp"
-    {yyval = yyvsp[-2] != yyvsp[0];}
-#line 1759 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-2] != yyvsp[0];}
+#line 1849 "ginsh_parser.cpp"
     break;
 
   case 43:
 #line 265 "ginsh_parser.ypp"
-    {yyval = yyvsp[-2] < yyvsp[0];}
-#line 1765 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-2] < yyvsp[0];}
+#line 1855 "ginsh_parser.cpp"
     break;
 
   case 44:
 #line 266 "ginsh_parser.ypp"
-    {yyval = yyvsp[-2] <= yyvsp[0];}
-#line 1771 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-2] <= yyvsp[0];}
+#line 1861 "ginsh_parser.cpp"
     break;
 
   case 45:
 #line 267 "ginsh_parser.ypp"
-    {yyval = yyvsp[-2] > yyvsp[0];}
-#line 1777 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-2] > yyvsp[0];}
+#line 1867 "ginsh_parser.cpp"
     break;
 
   case 46:
 #line 268 "ginsh_parser.ypp"
-    {yyval = yyvsp[-2] >= yyvsp[0];}
-#line 1783 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-2] >= yyvsp[0];}
+#line 1873 "ginsh_parser.cpp"
     break;
 
   case 47:
 #line 269 "ginsh_parser.ypp"
-    {yyval = yyvsp[-2] + yyvsp[0];}
-#line 1789 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-2] + yyvsp[0];}
+#line 1879 "ginsh_parser.cpp"
     break;
 
   case 48:
 #line 270 "ginsh_parser.ypp"
-    {yyval = yyvsp[-2] - yyvsp[0];}
-#line 1795 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-2] - yyvsp[0];}
+#line 1885 "ginsh_parser.cpp"
     break;
 
   case 49:
 #line 271 "ginsh_parser.ypp"
-    {yyval = yyvsp[-2] * yyvsp[0];}
-#line 1801 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-2] * yyvsp[0];}
+#line 1891 "ginsh_parser.cpp"
     break;
 
   case 50:
 #line 272 "ginsh_parser.ypp"
-    {yyval = yyvsp[-2] / yyvsp[0];}
-#line 1807 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-2] / yyvsp[0];}
+#line 1897 "ginsh_parser.cpp"
     break;
 
   case 51:
 #line 273 "ginsh_parser.ypp"
-    {yyval = -yyvsp[0];}
-#line 1813 "ginsh_parser.cpp"
+                                {yyval = -yyvsp[0];}
+#line 1903 "ginsh_parser.cpp"
     break;
 
   case 52:
 #line 274 "ginsh_parser.ypp"
-    {yyval = yyvsp[0];}
-#line 1819 "ginsh_parser.cpp"
+                                {yyval = yyvsp[0];}
+#line 1909 "ginsh_parser.cpp"
     break;
 
   case 53:
 #line 275 "ginsh_parser.ypp"
-    {yyval = power(yyvsp[-2], yyvsp[0]);}
-#line 1825 "ginsh_parser.cpp"
+                                {yyval = power(yyvsp[-2], yyvsp[0]);}
+#line 1915 "ginsh_parser.cpp"
     break;
 
   case 54:
 #line 276 "ginsh_parser.ypp"
-    {yyval = factorial(yyvsp[-1]);}
-#line 1831 "ginsh_parser.cpp"
+                                {yyval = factorial(yyvsp[-1]);}
+#line 1921 "ginsh_parser.cpp"
     break;
 
   case 55:
 #line 277 "ginsh_parser.ypp"
-    {yyval = yyvsp[-1];}
-#line 1837 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-1];}
+#line 1927 "ginsh_parser.cpp"
     break;
 
   case 56:
 #line 278 "ginsh_parser.ypp"
-    {yyval = yyvsp[-1];}
-#line 1843 "ginsh_parser.cpp"
+                                {yyval = yyvsp[-1];}
+#line 1933 "ginsh_parser.cpp"
     break;
 
   case 57:
 #line 279 "ginsh_parser.ypp"
-    {yyval = lst_to_matrix(ex_to<lst>(yyvsp[-1]));}
-#line 1849 "ginsh_parser.cpp"
+                                {yyval = lst_to_matrix(ex_to<lst>(yyvsp[-1]));}
+#line 1939 "ginsh_parser.cpp"
     break;
 
   case 58:
 #line 282 "ginsh_parser.ypp"
-    {yyval = exprseq{yyvsp[0]};}
-#line 1855 "ginsh_parser.cpp"
+                                {yyval = exprseq{yyvsp[0]};}
+#line 1945 "ginsh_parser.cpp"
     break;
 
   case 59:
 #line 283 "ginsh_parser.ypp"
-    {exprseq es(ex_to<exprseq>(yyvsp[-2])); yyval = es.append(yyvsp[0]);}
-#line 1861 "ginsh_parser.cpp"
+                                {exprseq es(ex_to<exprseq>(yyvsp[-2])); yyval = es.append(yyvsp[0]);}
+#line 1951 "ginsh_parser.cpp"
     break;
 
   case 60:
 #line 286 "ginsh_parser.ypp"
-    {yyval = *new lst;}
-#line 1867 "ginsh_parser.cpp"
+                                {yyval = *new lst;}
+#line 1957 "ginsh_parser.cpp"
     break;
 
   case 61:
 #line 287 "ginsh_parser.ypp"
-    {yyval = yyvsp[0];}
-#line 1873 "ginsh_parser.cpp"
+                                {yyval = yyvsp[0];}
+#line 1963 "ginsh_parser.cpp"
     break;
 
   case 62:
 #line 290 "ginsh_parser.ypp"
-    {yyval = lst{yyvsp[0]};}
-#line 1879 "ginsh_parser.cpp"
+                                {yyval = lst{yyvsp[0]};}
+#line 1969 "ginsh_parser.cpp"
     break;
 
   case 63:
 #line 291 "ginsh_parser.ypp"
-    {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
-#line 1885 "ginsh_parser.cpp"
+                                {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
+#line 1975 "ginsh_parser.cpp"
     break;
 
   case 64:
 #line 294 "ginsh_parser.ypp"
-    {yyval = lst{yyvsp[-1]};}
-#line 1891 "ginsh_parser.cpp"
+                                {yyval = lst{yyvsp[-1]};}
+#line 1981 "ginsh_parser.cpp"
     break;
 
   case 65:
 #line 295 "ginsh_parser.ypp"
-    {lst l(ex_to<lst>(yyvsp[-4])); yyval = l.append(yyvsp[-1]);}
-#line 1897 "ginsh_parser.cpp"
+                                 {lst l(ex_to<lst>(yyvsp[-4])); yyval = l.append(yyvsp[-1]);}
+#line 1987 "ginsh_parser.cpp"
     break;
 
   case 66:
 #line 298 "ginsh_parser.ypp"
-    {yyval = lst{yyvsp[0]};}
-#line 1903 "ginsh_parser.cpp"
+                                {yyval = lst{yyvsp[0]};}
+#line 1993 "ginsh_parser.cpp"
     break;
 
   case 67:
 #line 299 "ginsh_parser.ypp"
-    {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
-#line 1909 "ginsh_parser.cpp"
+                                {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
+#line 1999 "ginsh_parser.cpp"
     break;
 
 
-#line 1913 "ginsh_parser.cpp"
+#line 2003 "ginsh_parser.cpp"
 
       default: break;
     }
@@ -1973,7 +2063,7 @@ yyerrlab:
           {
             if (yymsg != yymsgbuf)
               YYSTACK_FREE (yymsg);
-            yymsg = (char *) YYSTACK_ALLOC (yymsg_alloc);
+            yymsg = YY_CAST (char *, YYSTACK_ALLOC (YY_CAST (YYSIZE_T, yymsg_alloc)));
             if (!yymsg)
               {
                 yymsg = yymsgbuf;
@@ -2128,7 +2218,7 @@ yyreturn:
   while (yyssp != yyss)
     {
       yydestruct ("Cleanup: popping",
-                  yystos[*yyssp], yyvsp);
+                  yystos[+*yyssp], yyvsp);
       YYPOPSTACK (1);
     }
 #ifndef yyoverflow
@@ -2714,7 +2804,7 @@ static void ginsh_readline_init(char* name)
 void greeting(void)
 {
     cout << "ginsh - GiNaC Interactive Shell (GiNaC V" << GINACLIB_VERSION << ")" << endl;
-    cout << "  __,  _______  Copyright (C) 1999-2019 Johannes Gutenberg University Mainz,\n"
+    cout << "  __,  _______  Copyright (C) 1999-2020 Johannes Gutenberg University Mainz,\n"
          << " (__) *       | Germany.  This is free software with ABSOLUTELY NO WARRANTY.\n"
          << "  ._) i N a C | You are welcome to redistribute it under certain conditions.\n"
          << "<-------------' For details type `warranty;'.\n" << endl;
